@@ -43,6 +43,7 @@ mod php;
 mod purescript;
 mod python;
 mod red;
+mod rlang;
 mod ruby;
 mod rust;
 mod scala;
@@ -118,6 +119,7 @@ pub fn handle<'a>(module: &str, context: &'a Context) -> Option<Module<'a>> {
             "php" => php::module(context),
             "purescript" => purescript::module(context),
             "python" => python::module(context),
+            "rlang" => rlang::module(context),
             "red" => red::module(context),
             "ruby" => ruby::module(context),
             "rust" => rust::module(context),
@@ -144,16 +146,14 @@ pub fn handle<'a>(module: &str, context: &'a Context) -> Option<Module<'a>> {
 
     let elapsed = start.elapsed();
     log::trace!("Took {:?} to compute module {:?}", elapsed, module);
-    if elapsed.as_millis() < 1 {
+    if elapsed.as_millis() >= 1 {
         // If we take less than 1ms to compute a None, then we will not return a module at all
         // if we have a module: default duration is 0 so no need to change it
-        m
-    } else {
         // if we took more than 1ms we want to report that and so--in case we have None currently--
         // need to create an empty module just to hold the duration for that case
         m.get_or_insert_with(|| context.new_module(module)).duration = elapsed;
-        m
     }
+    m
 }
 
 pub fn description(module: &str) -> &'static str {
@@ -201,6 +201,7 @@ pub fn description(module: &str) -> &'static str {
         "php" => "The currently installed version of PHP",
         "purescript" => "The currently installed version of PureScript",
         "python" => "The currently installed version of Python",
+        "rlang" => "The currently installed version of R",
         "red" => "The currently installed version of Red",
         "ruby" => "The currently installed version of Ruby",
         "rust" => "The currently installed version of Rust",
